@@ -3,7 +3,8 @@ import tensorflow as tf
 
 from xplique.attributions import (Saliency, GradientInput, IntegratedGradients, SmoothGrad, VarGrad,
                                   SquareGrad, GradCAM, Occlusion, Rise, GuidedBackprop, DeconvNet,
-                                  GradCAMPP, Lime, KernelShap, SobolAttributionMethod)
+                                  GradCAMPP, Lime, KernelShap, SobolAttributionMethod,
+                                  HsicAttributionMethod)
 from xplique.attributions.base import BlackBoxExplainer
 from ..utils import generate_data, generate_model
 
@@ -24,7 +25,8 @@ def _default_methods(model, output_layer_index):
         GradCAMPP(model, output_layer_index),
         Lime(model, nb_samples=2),
         KernelShap(model, nb_samples=2),
-        SobolAttributionMethod(model, grid_size=2, nb_design=2)
+        SobolAttributionMethod(model, grid_size=2, nb_design=2),
+        HsicAttributionMethod(model, grid_size=2, nb_design=2),
     ]
 
 
@@ -55,6 +57,9 @@ def test_common():
             # all explanations returned must be either a tf.Tensor or ndarray
             assert isinstance(explanations, (tf.Tensor, np.ndarray))
 
+            # we should have one explanation for each inputs
+            assert len(explanations) == len(inputs_np)
+
 
 def test_batch_size():
     """Ensure the functioning of attributions for special batch size cases"""
@@ -87,12 +92,13 @@ def test_batch_size():
         ]
 
         for method in methods:
-            try:
-                explanations = method.explain(inputs, targets)
-            except:
-                raise AssertionError(
-                    "Explanation failed for method ", method.__class__.__name__,
-                    " batch size ", bs)
+            explanations = method.explain(inputs, targets)
+
+            # all explanations returned must be either a tf.Tensor or ndarray
+            assert isinstance(explanations, (tf.Tensor, np.ndarray))
+
+            # we should have one explanation for each inputs
+            assert len(explanations) == len(inputs)
 
 
 def test_model_caching():
@@ -116,4 +122,4 @@ def test_model_caching():
 
     # ensure that there no more than one key has been added
     assert (len(
-        BlackBoxExplainer._cache_models) == cache_len_before + 1)  # pylint: disable=protected-access
+        BlackBoxExplainer._cache_models) == cache_len_before + 1)  # pylint: disable=protected-access
\ No newline at end of file
