@@ -36,7 +36,7 @@ class DeconvNet(WhiteBoxExplainer):
 
     def __init__(self,
                  model: tf.keras.Model,
-                 output_layer: Optional[Union[str, int]] = -1,
+                 output_layer: Optional[Union[str, int]] = None,
                  batch_size: Optional[int] = 32):
         super().__init__(model, output_layer, batch_size)
         self.model = override_relu_gradient(self.model, deconv_relu_policy)
