@@ -1,5 +1,5 @@
 """
 Utility functions to visualize explanations
 """
-from .image import plot_attributions
+from .image import plot_attributions, plot_attribution
 from .tabular import plot_feature_impact, plot_mean_feature_impact, summary_plot_tabular
